@@ -1,8 +1,9 @@
 from urllib.parse import urlencode
 import requests
+from .CONST import SB_User_Agent, SB_PROXY_CHATMEDIA
 
 
-def _get_ws_url(socket_base, params):
+def get_ws_url(socket_base, params):
     return f"{socket_base}/?{urlencode(params)}"
 
 
@@ -11,10 +12,10 @@ def print_chat_(resp, channelid_sub_pairs):
         print(f"{resp.user.name}@{channelid_sub_pairs.get(resp.channel_url)}: {resp.message}")
 
 
-def _get_current_channels(user_id, logi_key):
+def get_current_channels(user_id, logi_key):
     headers = {
         'session-key': logi_key,
-        'SB-User-Agent': 'Android%2Fc3.0.144',
+        'SB-User-Agent': SB_User_Agent,
         'User-Agent': None
     }
     params = {
@@ -26,11 +27,10 @@ def _get_current_channels(user_id, logi_key):
         'limit': '40',
         'show_empty': 'true'
     }
-    response = requests.get(f'https://sendbirdproxyk8s.chat.redditmedia.com/v3/users/{user_id}/my_group_channels',
-                            headers=headers, params=params).json()
+    response = requests.get(f'{SB_PROXY_CHATMEDIA}/v3/users/{user_id}/my_group_channels', headers=headers, params=params).json()
     channelid_sub_pairs = {}
-    room_name = None
     for channel in response.get('channels', {}):
+        room_name = None
         if channel['custom_type'] == "direct":
             for member in channel['members']:
                 if member['user_id'] != user_id:
